@@ -47,7 +47,6 @@ macro_rules! count {
 ///     // 这里要自行持有底层的 version.dll 的句柄，防止被释放。
 ///     let _ = forward_dll::load_library("C:\\Windows\\system32\\version.dll");
 ///     // 调用 forward_all 方法，建立导出函数与目标函数之间的映射关系。
-///     // 目前来说，这个方法是必须要调用的，因为 default_jumper 方法还有一些问题会导致崩溃，没有找到原因。
 ///     let _ = unsafe { DLL_VERSION_FORWARDER.forward_all() };
 ///   }
 ///   1
@@ -81,12 +80,15 @@ macro_rules! define_function {
                     "push rcx",
                     "push rdx",
                     "push r8",
+                    "push r9",
+                    "push r10",
+                    "push r11",
                     options(nostack)
                 );
                 std::arch::asm!(
-                    "sub rsp, 30h",
+                    "sub rsp, 28h",
                     "call rax",
-                    "add rsp, 30h",
+                    "add rsp, 28h",
                     in("rax") forward_dll::default_jumper,
                     in("rcx") std::concat!($lib, "\0").as_ptr() as usize,
                     in("rdx") std::concat!(std::stringify!($proc), "\0").as_ptr() as usize,
@@ -94,6 +96,9 @@ macro_rules! define_function {
                     options(nostack)
                 );
                 std::arch::asm!(
+                    "pop r11",
+                    "pop r10",
+                    "pop r9",
                     "pop r8",
                     "pop rdx",
                     "pop rcx",
